@@ -49,7 +49,7 @@ _shapes = {
 # a default PBR metallic material
 _default_material = {
     "pbrMetallicRoughness": {
-        "baseColorFactor": [0, 0, 0, 0],
+        "baseColorFactor": [1, 1, 1, 1],
         "metallicFactor": 0,
         "roughnessFactor": 0}}
 
@@ -484,6 +484,13 @@ def _create_gltf_structure(scene,
                 name=name,
                 tree=tree,
                 buffer_items=buffer_items)
+        elif util.is_instance_named(geometry, "PointCloud"):
+            # add PointCloud objects
+            _append_point(
+                points=geometry,
+                name=name,
+                tree=tree,
+                buffer_items=buffer_items)
 
     # cull empty or unpopulated fields
     # check keys that might be empty so we can remove them
@@ -577,9 +584,16 @@ def _append_mesh(mesh,
     assert len(buffer_items) >= tree['accessors'][-1]['bufferView']
 
     # check to see if we have vertex or face colors
+    # or if a TextureVisual has colors included as an attribute
     if mesh.visual.kind in ['vertex', 'face']:
-        # make sure colors are RGBA, this should always be true
         vertex_colors = mesh.visual.vertex_colors
+    elif (hasattr(mesh.visual, 'vertex_attributes') and
+          'color' in mesh.visual.vertex_attributes):
+        vertex_colors = mesh.visual.vertex_attributes['color']
+    else:
+        vertex_colors = None
+
+    if vertex_colors is not None:
         # add the reference for vertex color
         tree["meshes"][-1]["primitives"][0]["attributes"][
             "COLOR_0"] = len(tree["accessors"])
@@ -595,13 +609,15 @@ def _append_mesh(mesh,
             "byteOffset": 0})
         # the actual color data
         buffer_items.append(color_data)
-    elif hasattr(mesh.visual, 'material'):
+
+    if hasattr(mesh.visual, 'material'):
         # append the material and then set from returned index
         tree["meshes"][-1]["primitives"][0]["material"] = _append_material(
             mat=mesh.visual.material,
             tree=tree,
             buffer_items=buffer_items,
             mat_hashes=mat_hashes)
+
         # if mesh has UV coordinates defined export them
         has_uv = (hasattr(mesh.visual, 'uv') and
                   mesh.visual.uv is not None and
@@ -791,11 +807,91 @@ def _append_path(path, name, tree, buffer_items):
     # this is just exporting everying as black
     tree["materials"].append(_default_material)
 
-    # data is the second value of the fourth field
+    # data is the second value of the fifth field
     # which is a (data type, data) tuple
     buffer_items.append(_byte_pad(
         vxlist[4][1].astype(float32).tobytes()))
 
+    # add color to attributes
+    tree["meshes"][-1]["primitives"][0]["attributes"]["COLOR_0"] = len(tree["accessors"])
+
+    # the vertex color accessor data
+    tree["accessors"].append({
+        "bufferView": len(buffer_items),
+        "componentType": 5121,
+        "count": vxlist[0],
+        "normalized": True,
+        "type": "VEC4",
+        "byteOffset": 0})
+
+    # the actual color data
+    buffer_items.append(_byte_pad(
+        np.array(vxlist[5][1]).astype(uint8).tobytes()))
+
+
+def _append_point(points, name, tree, buffer_items):
+    """
+    Append a 2D or 3D pointCloud to the scene structure and put the
+    data into buffer_items.
+
+    Parameters
+    -------------
+    points : trimesh.PointCloud
+      Source geometry
+    name : str
+      Name of geometry
+    tree : dict
+      Will be updated with data from points
+    buffer_items
+      Will have buffer appended with points data
+    """
+
+    # convert the points to the unnamed args for
+    # a pyglet vertex list
+    vxlist = rendering.points_to_vertexlist(points=points.vertices, colors=points.colors)
+
+    tree["meshes"].append({
+        "name": name,
+        "primitives": [{
+            "attributes": {"POSITION": len(tree["accessors"])},
+            "mode": 0,  # mode 0 is GL_POINTS
+            "material": len(tree["materials"])}]})
+
+    tree["accessors"].append(
+        {
+            "bufferView": len(buffer_items),
+            "componentType": 5126,
+            "count": vxlist[0],
+            "type": "VEC3",
+            "byteOffset": 0,
+            "max": points.vertices.max(axis=0).tolist(),
+            "min": points.vertices.min(axis=0).tolist()})
+
+    # TODO add color support to Points object
+    # this is just exporting everying as black
+    tree["materials"].append(_default_material)
+
+    # data is the second value of the fifth field
+    # which is a (data type, data) tuple
+    buffer_items.append(_byte_pad(
+        vxlist[4][1].astype(float32).tobytes()))
+
+    # add color to attributes
+    tree["meshes"][-1]["primitives"][0]["attributes"]["COLOR_0"] = len(tree["accessors"])
+
+    # the vertex color accessor data
+    tree["accessors"].append({
+        "bufferView": len(buffer_items),
+        "componentType": 5121,
+        "count": vxlist[0],
+        "normalized": True,
+        "type": "VEC4",
+        "byteOffset": 0})
+
+    # the actual color data
+    buffer_items.append(_byte_pad(
+        np.array(vxlist[5][1]).astype(uint8).tobytes()))
+
 
 def _parse_materials(header, views, resolver=None):
     """
@@ -980,6 +1076,7 @@ def _read_buffers(header, buffers, mesh_kwargs, merge_primitives=False, resolver
                     dtype=np.int64).reshape((-1, 3))
 
             # do we have UV coordinates
+            visuals = None
             if "material" in p:
                 if materials is None:
                     log.warning('no materials! `pip install pillow`')
@@ -991,17 +1088,24 @@ def _read_buffers(header, buffers, mesh_kwargs, merge_primitives=False, resolver
                         uv = access[p["attributes"]["TEXCOORD_0"]].copy()
                         uv[:, 1] = 1.0 - uv[:, 1]
                         # create a texture visual
-                    kwargs["visual"] = visual.texture.TextureVisuals(
+                    visuals = visual.texture.TextureVisuals(
                         uv=uv, material=materials[p["material"]])
-            elif 'COLOR_0' in p['attributes']:
+            if 'COLOR_0' in p['attributes']:
                 try:
                     # try to load vertex colors from the accessors
                     colors = access[p['attributes']['COLOR_0']]
                     if len(colors) == len(kwargs['vertices']):
-                        kwargs['vertex_colors'] = colors
+                        if visuals is None:
+                            # just pass to mesh as vertex color
+                            kwargs['vertex_colors'] = colors
+                        else:
+                            # we ALSO have texture so save as vertex attribute
+                            visuals.vertex_attributes['color'] = colors
                 except BaseException:
                     # survive failed colors
-                    pass
+                    log.debug('failed to load colors', exc_info=True)
+            if visuals is not None:
+                kwargs['visual'] = visuals
 
             # create a unique mesh name per- primitive
             if "name" in m:
